==> hyphenate-chat-4.9.0.1-sources.jar: com/hyphenate/chat/adapter/message/EMAImageMessageBody.java <==
/*
 *  * EaseMob CONFIDENTIAL
 * __________________
 * Copyright (C) 2017 EaseMob Technologies. All rights reserved.
 *
 * NOTICE: All information contained herein is, and remains
 * the property of EaseMob Technologies.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from EaseMob Technologies.
 */
package com.hyphenate.chat.adapter.message;

import android.net.Uri;

import com.hyphenate.util.EMFileHelper;

public class EMAImageMessageBody extends EMAFileMessageBody {
	public double width;
	public double height;
	public long fileLength;
	
	public String thumbnailLocalPath;
	public String thumbnailRemotePath;
	public String thumbnailSecretKey;
	public int thumbnailDownloadStatus;

    /**
     * @param localPath
     * @param thumbnailLocalPath
     */
	public EMAImageMessageBody(String localPath, String thumbnailLocalPath) {
        super(localPath, EMAMessageBodyType_IMAGE);
        nativeInit(localPath, thumbnailLocalPath);
	}

	public EMAImageMessageBody(Uri localPath, Uri thumbnailLocalPath) {
		super(localPath, EMAMessageBodyType_IMAGE);
		nativeInit(EMFileHelper.getInstance().uriToString(localPath), EMFileHelper.getInstance().uriToString(thumbnailLocalPath));
	}

	public EMAImageMessageBody(EMAImageMessageBody body) {
		super("", EMAMessageBodyType_IMAGE);
		nativeInit(body);
	}
	
	// used by jni_util.cpp: getJObject
	private EMAImageMessageBody() {
		super("", EMAMessageBodyType_IMAGE);
		nativeInit("", "");
	}
	
	@Override
	public void finalize() throws Throwable {
		nativeFinalize();
		super.finalize();
	}
	
    /**
      * \brief Set display name of the thumbnail.
      *
      * @param  The display name.
      * @return NA
      */
    public void setThumbnailDisplayName(String displayName) {
    	nativesetThumbnailDisplayName(displayName);
    }
    native void nativesetThumbnailDisplayName(String displayName);
    
    /**
      * \brief Get display name of the thumbnail.
      *
      * @param  NA
      * @return The display name.
      */
    public String thumbnailDisplayName() {
    	return nativethumbnailDisplayName();
    }
    native String nativethumbnailDisplayName();
    
    /**
      * \brief Set local path of the thumbnail.
      *
      * @param  The local path.
      * @return NA
      */
    public void setThumbnailLocalPath(String thumbnailLocalPath) {
    	nativesetThumbnailLocalPath(thumbnailLocalPath );
    }
    native void nativesetThumbnailLocalPath(String thumbnailLocalPath);
    
    /**
      * \brief Get local path of the thumbnail.
      *
      * @param  NA
      * @return The local path.
      */
    public String thumbnailLocalPath() {
    	return nativethumbnailLocalPath();
    }
    native String nativethumbnailLocalPath();
    
    /**
      * \brief Set remote path of the thumbnail.
      *
      * Note: It's internal used, user should never need to call this method.
      * @param  The remote path.
      * @return NA
      */
    public void setThumbnailRemotePath(String thumbnailRemotePath) {
    	nativesetThumbnailRemotePath(thumbnailRemotePath);
    }
    native void nativesetThumbnailRemotePath(String thumbnailRemotePath);
    
    /**
      * \brief Get remote path of the thumbnail.
      *
      * @param  NA
      * @return The remote path.
      */
    public String thumbnailRemotePath() {
    	return nativethumbnailRemotePath();
    }
    native String nativethumbnailRemotePath();
    
    /**
      * \brief Set secret key of the thumbnail.
      *
      * Note: It's internal used, user should never need to call this method.
      * @param  The secret key.
      * @return NA
      */
    public void setThumbnailSecretKey(String secretKey) {
    	nativesetThumbnailSecretKey(secretKey);
    }
    native void nativesetThumbnailSecretKey(String secretKey);
    
    /**
      * \brief Get secret key of the thumbnail.
      *
      * @param  NA
      * @return The secret key.
      */
    public String thumbnailSecretKey() {
    	return nativethumbnailSecretKey();
    }
    native String nativethumbnailSecretKey();
    
    /**
      * \brief Set size of the thumbnail.
      *
      * @param  The thumbnail size.
      * @return NA
      */
    public void setThumbnailSize(int width, int height ) {
    	nativesetThumbnailSize(width, height );
    }
    native void nativesetThumbnailSize(int width, int height);
    
    /**
      * \brief Get width of the thumbnail.
      *
      * @param  NA
      * @return The thumbnail width.
      */
    public int thumbnailWidth() {
    	return nativethumbnailWidth();
    }
    native int nativethumbnailWidth();
    
    /**
     * \brief Get width of the thumbnail.
   	 *
     * @param  NA
     * @return The thumbnail width.
     */
    int thumbnailHeight() {
    	return nativethumbnailHeight();
    }
    native int nativethumbnailHeight();

   
    /**
      * \brief Set file length of the thumbnail.
      *
      * Note: It's usually not necessary to call this method, will calculate file length automatically when setting local path.
      * @param  The file length.
      * @return NA
      */
   public void setThumbnailFileLength(long fileLength) {
    	nativesetThumbnailFileLength(fileLength);
    }
    native void nativesetThumbnailFileLength(long fileLength);
    
    /**
      * \brief Get file length of the thumbnail.
      *
      * @param  NA
      * @return The file length.
      */
    public long thumbnailFileLength() {
    	return nativethumbnailFileLength();
    }
    native long nativethumbnailFileLength();
    
    /**
      * \brief Set download status of the thumbnail.
      *
      * Note: Usually, user should NOT call this method directly.
      * @param  The download status.
      * @return NA
      */
    public void setThumbnailDownloadStatus(EMADownloadStatus status) {
    	int s = status.ordinal();
    	nativesetThumbnailDownloadStatus(s);
    }
    native void nativesetThumbnailDownloadStatus(int status);
    
    /**
      * \brief Get download status of the thumbnail.
      *
      * @param  NA
      * @return The download status.
      */
    public EMADownloadStatus thumbnailDownloadStatus() {
    	int s = nativethumbnailDownloadStatus();
    	
    	if (s == EMADownloadStatus.DOWNLOADING.ordinal()) {
    	    return EMADownloadStatus.DOWNLOADING;
    	} else if (s == EMADownloadStatus.SUCCESSED.ordinal()) {
    	    return EMADownloadStatus.SUCCESSED;
    	} else if (s == EMADownloadStatus.FAILED.ordinal()) {
    	    return EMADownloadStatus.FAILED;
    	} else {
    	    return EMADownloadStatus.PENDING;
    	}
    }
    native int nativethumbnailDownloadStatus();
    
    /**
      * \brief Set size of the image.
      *
      * @param  The image's width.
      * @param  The image's height.
      * @return NA
      */
    public void setSize(int width, int height) {
    	nativesetSize(width, height);
    }
    native void nativesetSize(int width, int height);

   
    /**
      * \brief Get width of the image.
      *
      * @param  NA
      * @return The image width.
      */
   public int width() {
    	return nativewidth();
    }
    native int nativewidth();
	
    /**
     * \brief Get height of the image.
     *
     * @param  NA
     * @return The image height.
     */
    public int height() {
    	return nativeheight();
    }
    native int nativeheight();

    /**
     * \brief Set original local path if not sending original image.
     * @param originalLocalPath
     */
    public void setOriginalLocalPath(String originalLocalPath) { nativeSetOriginalLocalPath(originalLocalPath); }
    native void nativeSetOriginalLocalPath(String originalLocalPath);

    /**
     * \brief Get original local path if not sending original image.
     * @return
     */
    public String getOriginalLocalPath() { return nativeGetOriginalLocalPath();}
    native String nativeGetOriginalLocalPath();

    native void nativeInit(String localPath, String thumbnailLocalPath);
	native void nativeInit(EMAImageMessageBody body);
	native void nativeFinalize();

}

==> hyphenate-chat-4.17.1-sources.jar: com/hyphenate/chat/adapter/message/EMAImageMessageBody.java <==
/*
 *  * EaseMob CONFIDENTIAL
 * __________________
 * Copyright (C) 2017 EaseMob Technologies. All rights reserved.
 *
 * NOTICE: All information contained herein is, and remains
 * the property of EaseMob Technologies.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from EaseMob Technologies.
 */
package com.hyphenate.chat.adapter.message;

import android.net.Uri;

import com.hyphenate.util.EMFileHelper;

public class EMAImageMessageBody extends EMAFileMessageBody {
	public double width;
	public double height;
	public long fileLength;
	
	public String thumbnailLocalPath;
	public String thumbnailRemotePath;
	public String thumbnailSecretKey;
	public int thumbnailDownloadStatus;

    /**
     * @param localPath
     * @param thumbnailLocalPath
     */
	public EMAImageMessageBody(String localPath, String thumbnailLocalPath) {
        super(localPath, EMAMessageBodyType_IMAGE);
        nativeInit(localPath, thumbnailLocalPath);
	}

	public EMAImageMessageBody(Uri localPath, Uri thumbnailLocalPath) {
		super(localPath, EMAMessageBodyType_IMAGE);
		nativeInit(EMFileHelper.getInstance().uriToString(localPath), EMFileHelper.getInstance().uriToString(thumbnailLocalPath));
	}

	public EMAImageMessageBody(EMAImageMessageBody body) {
		super("", EMAMessageBodyType_IMAGE);
		nativeInit(body);
	}
	
	// used by jni_util.cpp: getJObject
	private EMAImageMessageBody() {
		super("", EMAMessageBodyType_IMAGE);
		nativeInit("", "");
	}
	
	@Override
	public void finalize() throws Throwable {
		nativeFinalize();
		super.finalize();
	}
	
    /**
      * \brief Set display name of the thumbnail.
      *
      * @param  The display name.
      * @return NA
      */
    public void setThumbnailDisplayName(String displayName) {
    	nativesetThumbnailDisplayName(displayName);
    }
    native void nativesetThumbnailDisplayName(String displayName);
    
    /**
      * \brief Get display name of the thumbnail.
      *
      * @param  NA
      * @return The display name.
      */
    public String thumbnailDisplayName() {
    	return nativethumbnailDisplayName();
    }
    native String nativethumbnailDisplayName();
    
    /**
      * \brief Set local path of the thumbnail.
      *
      * @param  The local path.
      * @return NA
      */
    public void setThumbnailLocalPath(String thumbnailLocalPath) {
    	nativesetThumbnailLocalPath(thumbnailLocalPath );
    }
    native void nativesetThumbnailLocalPath(String thumbnailLocalPath);
    
    /**
      * \brief Get local path of the thumbnail.
      *
      * @param  NA
      * @return The local path.
      */
    public String thumbnailLocalPath() {
    	return nativethumbnailLocalPath();
    }
    native String nativethumbnailLocalPath();
    
    /**
      * \brief Set remote path of the thumbnail.
      *
      * Note: It's internal used, user should never need to call this method.
      * @param  The remote path.
      * @return NA
      */
    public void setThumbnailRemotePath(String thumbnailRemotePath) {
    	nativesetThumbnailRemotePath(thumbnailRemotePath);
    }
    native void nativesetThumbnailRemotePath(String thumbnailRemotePath);
    
    /**
      * \brief Get remote path of the thumbnail.
      *
      * @param  NA
      * @return The remote path.
      */
    public String thumbnailRemotePath() {
    	return nativethumbnailRemotePath();
    }
    native String nativethumbnailRemotePath();
    
    /**
      * \brief Set secret key of the thumbnail.
      *
      * Note: It's internal used, user should never need to call this method.
      * @param  The secret key.
      * @return NA
      */
    public void setThumbnailSecretKey(String secretKey) {
    	nativesetThumbnailSecretKey(secretKey);
    }
    native void nativesetThumbnailSecretKey(String secretKey);
    
    /**
      * \brief Get secret key of the thumbnail.
      *
      * @param  NA
      * @return The secret key.
      */
    public String thumbnailSecretKey() {
    	return nativethumbnailSecretKey();
    }
    native String nativethumbnailSecretKey();
    
    /**
      * \brief Set size of the thumbnail.
      *
      * @param  The thumbnail size.
      * @return NA
      */
    public void setThumbnailSize(int width, int height ) {
    	nativesetThumbnailSize(width, height );
    }
    native void nativesetThumbnailSize(int width, int height);
    
    /**
      * \brief Get width of the thumbnail.
      *
      * @param  NA
      * @return The thumbnail width.
      */
    public int thumbnailWidth() {
    	return nativethumbnailWidth();
    }
    native int nativethumbnailWidth();
    
    /**
     * \brief Get width of the thumbnail.
   	 *
     * @param  NA
     * @return The thumbnail width.
     */
    int thumbnailHeight() {
    	return nativethumbnailHeight();
    }
    native int nativethumbnailHeight();

   
    /**
      * \brief Set file length of the thumbnail.
      *
      * Note: It's usually not necessary to call this method, will calculate file length automatically when setting local path.
      * @param  The file length.
      * @return NA
      */
   public void setThumbnailFileLength(long fileLength) {
    	nativesetThumbnailFileLength(fileLength);
    }
    native void nativesetThumbnailFileLength(long fileLength);
    
    /**
      * \brief Get file length of the thumbnail.
      *
      * @param  NA
      * @return The file length.
      */
    public long thumbnailFileLength() {
    	return nativethumbnailFileLength();
    }
    native long nativethumbnailFileLength();
    
    /**
      * \brief Set download status of the thumbnail.
      *
      * Note: Usually, user should NOT call this method directly.
      * @param  The download status.
      * @return NA
      */
    public void setThumbnailDownloadStatus(EMADownloadStatus status) {
    	int s = status.ordinal();
    	nativesetThumbnailDownloadStatus(s);
    }
    native void nativesetThumbnailDownloadStatus(int status);
    
    /**
      * \brief Get download status of the thumbnail.
      *
      * @param  NA
      * @return The download status.
      */
    public EMADownloadStatus thumbnailDownloadStatus() {
    	int s = nativethumbnailDownloadStatus();
    	
    	if (s == EMADownloadStatus.DOWNLOADING.ordinal()) {
    	    return EMADownloadStatus.DOWNLOADING;
    	} else if (s == EMADownloadStatus.SUCCESSED.ordinal()) {
    	    return EMADownloadStatus.SUCCESSED;
    	} else if (s == EMADownloadStatus.FAILED.ordinal()) {
    	    return EMADownloadStatus.FAILED;
    	} else {
    	    return EMADownloadStatus.PENDING;
    	}
    }
    native int nativethumbnailDownloadStatus();
    
    /**
      * \brief Set size of the image.
      *
      * @param  The image's width.
      * @param  The image's height.
      * @return NA
      */
    public void setSize(int width, int height) {
    	nativesetSize(width, height);
    }
    native void nativesetSize(int width, int height);

   
    /**
      * \brief Get width of the image.
      *
      * @param  NA
      * @return The image width.
      */
   public int width() {
    	return nativewidth();
    }
    native int nativewidth();
	
    /**
     * \brief Get height of the image.
     *
     * @param  NA
     * @return The image height.
     */
    public int height() {
    	return nativeheight();
    }
    native int nativeheight();

    /**
     * \brief Set original local path if not sending original image.
     * @param originalLocalPath
     */
    public void setOriginalLocalPath(String originalLocalPath) { nativeSetOriginalLocalPath(originalLocalPath); }
    native void nativeSetOriginalLocalPath(String originalLocalPath);

    /**
     * \brief Get original local path if not sending original image.
     * @return
     */
    public String getOriginalLocalPath() { return nativeGetOriginalLocalPath();}
    native String nativeGetOriginalLocalPath();

    public boolean isGif() {
        return nativeIsGif();
    }

    public void setGif(boolean isGif) {
        nativeSetGif(isGif);
    }

    public native boolean nativeIsGif();
    public native void nativeSetGif(boolean isGif);
    native void nativeInit(String localPath, String thumbnailLocalPath);
	native void nativeInit(EMAImageMessageBody body);
	native void nativeFinalize();

}
